;; Generated package description from xref.el  -*- no-byte-compile: t -*-
(define-package "xref" "1.6.3.0.20240525.230313" "Cross-referencing commands" '((emacs "26.1")) :commit "b241ec0e78f141e7fc22cf3afb11037d14fc028c" :url "https://elpa.gnu.org/packages/xref.html")
